@@ -1,9 +1,9 @@
-# @(#)$Ident: StringifyingError.pm 2013-08-02 19:53 pjf ;
+# @(#)$Ident: StringifyingError.pm 2013-08-23 23:01 pjf ;
 
 package Unexpected::TraitFor::StringifyingError;
 
 use namespace::sweep;
-use version; our $VERSION = qv( sprintf '0.8.%d', q$Rev: 1 $ =~ /\d+/gmx );
+use version; our $VERSION = qv( sprintf '0.9.%d', q$Rev: 1 $ =~ /\d+/gmx );
 
 use Unexpected::Functions   qw( build_attr_from inflate_message );
 use Unexpected::Types       qw( ArrayRef Str );
@@ -37,7 +37,7 @@ after 'BUILD' => sub {
 
 # Public methods
 sub as_string { # Stringifies the error and inflates the placeholders
-   my $self = shift; my $error = $self->error; defined $error or return;
+   my $self = shift; my $error = $self->error;
 
    0 > index $error, '[_' and return $error."\n";
 
@@ -60,7 +60,7 @@ Unexpected::TraitFor::StringifyingError - Base role for exception handling
 
 =head1 Version
 
-This documents version v0.8.$Rev: 1 $ of
+This documents version v0.9.$Rev: 1 $ of
 L<Unexpected::TraitFor::StringifyingError>
 
 =head1 Synopsis
